@@ -45,5 +45,8 @@ def pytest_collect_file(parent, path):
         and NATIVE_TESTS in path.dirname + os.sep
         and path.basename != "__init__.hy"):
 
-        pytest_mod = pytest.Module(path, parent)
+        if hasattr(pytest.Module, "from_parent"):
+            pytest_mod = pytest.Module.from_parent(parent, fspath=path)
+        else:
+            pytest_mod = pytest.Module(path, parent)
         return pytest_mod
