@@ -7,7 +7,7 @@ from __future__ import unicode_literals
 
 from hy import HyString
 from hy.compiler import hy_compile, hy_eval
-from hy.errors import HyCompileError, HyLanguageError, HyError
+from hy.errors import HyLanguageError, HyError
 from hy.lex import hy_parse
 from hy.lex.exceptions import LexException, PrematureEndOfInput
 from hy._compat import PY36
@@ -36,14 +36,11 @@ def can_eval(expr):
 def cant_compile(expr):
     with pytest.raises(HyError) as excinfo:
         hy_compile(hy_parse(expr), __name__)
-
-    if issubclass(excinfo.type, HyLanguageError):
-        assert excinfo.value.msg
-        return excinfo.value
-    elif issubclass(excinfo.type, HyCompileError):
-        # Anything that can't be compiled should raise a user friendly
-        # error, otherwise it's a compiler bug.
-        return excinfo.value
+    # Anything that can't be compiled should raise a user friendly
+    # error, otherwise it's a compiler bug.
+    assert issubclass(excinfo.type, HyLanguageError)
+    assert excinfo.value.msg
+    return excinfo.value
 
 
 def s(x):
@@ -297,6 +294,17 @@ import a dotted name."""
     cant_compile("(require [spam [foo.bar]])")
 
 
+def test_ast_multi_require():
+    # https://github.com/hylang/hy/issues/1903
+    x = can_compile("""(require
+      [tests.resources.tlib [qplah]]
+      [tests.resources.macros [threadtail-set-cd]])""")
+    assert sum(1 for stmt in x.body if isinstance(stmt, ast.Expr)) == 2
+    dump = ast.dump(x)
+    assert "qplah" in dump
+    assert "threadtail" in dump
+
+
 def test_ast_good_get():
     "Make sure AST can compile valid get"
     can_compile("(get x y)")
@@ -485,7 +493,6 @@ def test_ast_unicode_vs_bytes():
     assert s('b"\\xa0"') == bytes([160])
 
 
-@pytest.mark.skipif(not PY36, reason='f-strings require Python 3.6+')
 def test_format_string():
     assert can_compile('f"hello world"')
     assert can_compile('f"hello {(+ 1 1)} world"')
